@@ -5,11 +5,12 @@ from __future__ import absolute_import, division, print_function
 import tensorflow as tf
 import tensorflow.contrib.slim as slim
 
-from libs.models.detectors.single_stage_base_network import DetectionNetworkBase
-from libs.models.losses.losses_gwd import LossGWD
-from libs.utils import bbox_transform, nms_rotate
-from libs.models.samplers.retinanet.anchor_sampler_retinenet import AnchorSamplerRetinaNet
-from libs.models.samplers.r3det.refine_anchor_sampler_r3det import RefineAnchorSamplerR3Det
+from alpharotate.libs.models.detectors.single_stage_base_network import DetectionNetworkBase
+from alpharotate.libs.models.losses.losses_gwd import LossGWD
+from alpharotate.libs.utils import bbox_transform
+from alpharotate.libs.utils import nms_rotate
+from alpharotate.libs.models.samplers.retinanet.anchor_sampler_retinenet import AnchorSamplerRetinaNet
+from alpharotate.libs.models.samplers.r3det.refine_anchor_sampler_r3det import RefineAnchorSamplerR3Det
 
 
 class DetectionNetworkR3DetGWD(DetectionNetworkBase):
