@@ -7,7 +7,7 @@
 # --------------------------------------------------------
 import torch
 
-from libs.utils.nms_cython.cpu_nms import cpu_nms, cpu_soft_nms
+from alpharotate.libs.utils.nms_cython.cpu_nms import cpu_nms, cpu_soft_nms
 
 
 def nms(dets, thresh, use_gpu=True):
